@@ -9,8 +9,13 @@ from pyecharts.globals import ThemeType
 import pymysql
 from sqlalchemy import create_engine
 from hbshare.quant.cons import index_underlying
-from hbshare.quant.fut import wind_index_fut_amount, wind_com_fut_sec_index_amount, fin_fut_daily_k_by_contracts
-from hbshare.quant.cons import sql_write_path_hb, HSJY_VIRTUAL_CONTRACT
+from hbshare.quant.fut import (
+    wind_index_fut_amount,
+    wind_com_fut_sec_index_amount,
+    fin_fut_daily_k_by_contracts,
+    fut_com_amount_by_ex
+)
+from hbshare.quant.cons import sql_write_path_hb, HSJY_VIRTUAL_CONTRACT, exchange_dict
 
 pymysql.install_as_MySQLdb()
 
@@ -659,6 +664,110 @@ def chart_freq_dist(
     return grid
 
 
+def chart_fut_com_amt(start_date=None, end_date=None, grid_width=1200, grid_height=600):
+    data = pd.DataFrame(fut_com_amount_by_ex(start_date=start_date, end_date=end_date)['data'])
+    data['ENDDATE'] = pd.to_datetime(data['ENDDATE']).dt.date.tolist()
+    data['SUM(TURNOVER)'] = data['SUM(TURNOVER)'] / 100000000
+    data.loc[
+        data['ENDDATE'] < datetime(2020, 1, 1).date(), 'SUM(TURNOVER)'
+    ] = data.loc[
+                data['ENDDATE'] < datetime(2020, 1, 1).date(), 'SUM(TURNOVER)'
+            ] / 2
+    # ex_list = data['EXCHANGE'].drop_duplicates().tolist()
+    # calendar = data[['ENDDATE']].drop_duplicates().reset_index(drop=True)
+    # calendar['ENDDATE'] = pd.to_datetime(calendar['ENDDATE']).dt.date.tolist()
+
+    web = Line(
+    ).add_xaxis(
+        xaxis_data=data['ENDDATE'].tolist()
+    )
+    web.add_yaxis(
+        series_name='AMOUNT',
+        y_axis=data['SUM(TURNOVER)'].tolist(),
+        # stack='总量',
+        label_opts=opts.LabelOpts(is_show=False),
+        areastyle_opts=opts.AreaStyleOpts(opacity=0.5),
+    )
+
+    # for i in ex_list:
+    #     data_e = data[['ENDDATE', 'TURNOVER']].groupby(by='ENDDATE').sum().reset_index()
+    #     data_e['TURNOVER'] = data_e['TURNOVER'] / 100000000
+    #
+    #     web.add_yaxis(
+    #         series_name=exchange_dict[i],
+    #         y_axis=data_e['TURNOVER'].tolist(),
+    #         stack='总量',
+    #         label_opts=opts.LabelOpts(is_show=False),
+    #         areastyle_opts=opts.AreaStyleOpts(opacity=0.5),
+    #     )
+
+    web.set_global_opts(
+        title_opts=opts.TitleOpts(title="每日期货成交额(亿元) " + data['ENDDATE'].tolist()[-1].strftime('%Y-%m-%d')),
+        tooltip_opts=opts.TooltipOpts(trigger="axis", axis_pointer_type="cross"),
+        yaxis_opts=opts.AxisOpts(
+            type_="value",
+            axislabel_opts=opts.LabelOpts(formatter="{value} 亿元"),
+            axistick_opts=opts.AxisTickOpts(is_show=True),
+            splitline_opts=opts.SplitLineOpts(is_show=True),
+        ),
+        xaxis_opts=opts.AxisOpts(type_="category", boundary_gap=False),
+        datazoom_opts=[
+            opts.DataZoomOpts(
+                range_start=0,
+                range_end=100,
+                # is_show=False,
+                type_="inside",
+                # xaxis_index=[0, 1],
+            ),
+            opts.DataZoomOpts(
+                #     is_show=True,
+                #     xaxis_index=[0, 1],
+                #     type_="slider",
+                #     pos_top="90%",
+                #     range_start=98,
+                #     range_end=100,
+            ),
+        ],
+        legend_opts=opts.LegendOpts(
+            pos_top="7%",
+            pos_left='10%',
+            pos_right='10%'
+        )
+    )
+    # web2.set_global_opts(
+    #     legend_opts=opts.LegendOpts(
+    #         pos_top="7%",
+    #         pos_left='10%',
+    #         pos_right='20%'
+    #     )
+    # )
+    grid = (
+        Grid(
+            init_opts=opts.InitOpts(
+                width=str(grid_width) + "px",
+                height=str(grid_height) + "px"
+            ),
+        ).add(
+            web, grid_opts=opts.GridOpts(
+                pos_right="20%",
+                pos_left="10%",
+                pos_top='20%',
+                # pos_bottom='50%'
+            ),
+            # is_control_axis_index=True
+            # ).add(
+            #     web2, grid_opts=opts.GridOpts(
+            #         pos_right="20%",
+            #         pos_left="10%",
+            #         pos_top='55%',
+            #         pos_bottom='15%'
+            #     ),
+        )
+    )
+
+    return grid
+
+
 # def chart_ret_with_index(
 #         funds, end_date, lookback_year, grid_width=1200, grid_height=600, interval=0.5,
 #         dtype='', fillna=False, freq='w',
