@@ -73,7 +73,7 @@ def load_funds_data(
     cal_spe = load_calendar_extra(freq=freq, end_date=end_date, db_path=cal_db_path)
     cal_all = cal_spe.copy()
     i_dates = []
-    if len(fund_list) == 0:
+    if len(fund_list) == 1:
         sql_l = 'code=\'' + fund_list['code'][0] + '\''
     else:
         sql_l = 'code in ' + str(tuple(fund_list['code']))
@@ -164,7 +164,7 @@ def load_funds_alpha(
     cal_eav = cal_spe.copy()
     cal_excess = cal_spe.copy()
 
-    if len(fund_list) == 0:
+    if len(fund_list) == 1:
         sql_l = 'code=\'' + fund_list['code'][0] + '\''
     else:
         sql_l = 'code in ' + str(tuple(fund_list['code']))
@@ -190,6 +190,10 @@ def load_funds_alpha(
             ][['t_date', 'nav']].rename(columns={'nav': fund_name})
         fund_data = fund_data.drop_duplicates(['t_date'], keep='first').reset_index(drop=True)
 
+        # 衍复指增三号特殊处理
+        if fund_code == 'SJH866'.lower():
+            fund_data = fund_data[fund_data['t_date'] >= datetime(2020, 2, 14).date()].reset_index(drop=True)
+
         benchmark_data = pd.read_sql_query(
             'select t_date, close from ' + index_table
             + ' where t_date<=' + end_date.strftime('%Y%m%d')
